=== modified file 'bzrlib/globbing.py'
--- bzrlib/globbing.py	2007-03-01 08:46:00 +0000
+++ bzrlib/globbing.py	2007-03-02 00:34:38 +0000
@@ -109,7 +109,12 @@
 
 
 def _trailing_backslashes_regex(m):
-    if len(m) %2  != 0:
+    """Check trailing backslashes.
+
+    Does a head count on trailing backslashes to ensure there isn't an odd
+    one on the end that would escape the brackets we wrap the RE in.
+    """
+    if (len(m) % 2) != 0:
         warning(u"Regular expressions cannot end with an odd number of '\\'. "
                 "Dropping the final '\\'.")
         return m[:-1]
@@ -211,14 +216,11 @@
         return None
         
 
-_normalize_re = re.compile(ur'\\(?!x\d\d|\d\d\d|u\d\d\d\d)')
-
-
 def normalize_pattern(pattern):
     """Converts backslashes in path patterns to forward slashes.
-     
-    Avoids converting escape backslashes.
+    
+    Doesn't normalize regular expressions - they may contain escapes.
     """
     if not pattern.startswith('RE:'):
-        pattern = _normalize_re.sub('/', pattern)
+        pattern = pattern.replace('\\','/')
     return pattern.rstrip('/')

=== modified file 'bzrlib/tests/test_globbing.py'
--- bzrlib/tests/test_globbing.py	2007-03-01 08:46:00 +0000
+++ bzrlib/tests/test_globbing.py	2007-03-02 00:34:38 +0000
@@ -114,32 +114,32 @@
             (u'[a-z]',
              [u'a', u'q', u'f'],
              [u'A', u'Q', u'F']),
-            (ur'[^a-z]',
+            (u'[^a-z]',
              [u'A', u'Q', u'F'],
              [u'a', u'q', u'f']),
             (u'[!a-z]foo',
              [u'Afoo', u'.foo'],
              [u'afoo', u'ABfoo']),
-            (ur'foo[!a-z]bar',
+            (u'foo[!a-z]bar',
              [u'fooAbar', u'foo.bar'],
              [u'foojbar']),
-            (ur'[\x20-\x30\u8336]',
+            (u'[\x20-\x30\u8336]',
              [u'\040', u'\044', u'\u8336'],
              [u'\x1f']),
-            (ur'[^\x20-\x30\u8336]',
+            (u'[^\x20-\x30\u8336]',
              [u'\x1f'],
              [u'\040', u'\044', u'\u8336']),
             ])
 
     def test_regex(self):
         self.assertMatch([
-            (ur'RE:(a|b|c+)',
-             [u'a', u'b', u'ccc'],
-             [u'd', u'aa', u'c+', u'-a']),
-            (ur'RE:(?:a|b|c+)',
-             [u'a', u'b', u'ccc'],
-             [u'd', u'aa', u'c+', u'-a']),
-            (ur'RE:(?P<a>.)(?P=a)',
+            (u'RE:(a|b|c+)',
+             [u'a', u'b', u'ccc'],
+             [u'd', u'aa', u'c+', u'-a']),
+            (u'RE:(?:a|b|c+)',
+             [u'a', u'b', u'ccc'],
+             [u'd', u'aa', u'c+', u'-a']),
+            (u'RE:(?P<a>.)(?P=a)',
              [u'a'],
              [u'ab', u'aa', u'aaa']),
             # test we can handle odd numbers of trailing backslashes

